==> moodle-1.4.3.tgz: moodle/lang/es/survey.php <==
<?PHP // $Id$ 
      // survey.php - created with Moodle 1.3 (2004052500)


$string['actual'] = 'Actual';
$string['actualclass'] = 'Clase actual';
$string['actualstudent'] = '$a actual';
$string['allquestions'] = 'Todas las preguntas en orden, todos los estudiantes';
$string['allscales'] = 'Todas las escalas, todos los estudiantes';
$string['alreadysubmitted'] = 'Ya envi esta informacin';
$string['analysisof'] = 'Anlisis de $a';
$string['answers'] = 'Respuestas';
$string['attls1'] = 'Al evaluar lo que alguien dice, me centro en lo que dice y no en quin es.';
$string['attls10'] = 'Para m es importante mantenerme lo ms objetivo posible cuando analizo algo.';
$string['attls10short'] = 'Sea objetivo';
$string['attls11'] = 'Trato de pensar con las personas en lugar de contra ellas.';
$string['attls11short'] = 'Piense CON las personas';
$string['attls12'] = 'Tengo un criterio que utilizo para evaluar argumentos.';
$string['attls12short'] = 'Utilice un criterio para evaluar';
$string['attls13'] = 'Prefiero tratar de entender a los dems antes que evaluarlos.';
$string['attls13short'] = 'Trate de entender';
$string['attls14'] = 'Trato de sealar las debilidades en la manera de pensar de los dems para ayudarles a clarificar sus razonamientos.';
$string['attls14short'] = 'Seale los puntos dbiles';
$string['attls15'] = 'Trato de colocarme en el lugar de los dems para comprender cmo piensan y por qu.';
$string['attls15short'] = 'Me coloco en el lugar de los otros';
$string['attls16'] = 'Alguien podra llamar a mi manera de analizar las cosas \'ponerlas a prueba\' porque yo tengo en cuenta todas las evidencias cuidadosamente.';
$string['attls16short'] = 'poner a prueba';
$string['attls17'] = 'Cuando se trata de resolver problemas, valoro el uso de la lgica y de la razn por encima de mis propios intereses.';
$string['attls17short'] = 'valoro sobre todo la lgica';
$string['attls18'] = 'puedo llegar a entender las opiniones que difieren de la ma a travs de la empata';
$string['attls18short'] = 'entendimiento desde la empata';
$string['attls19'] = 'Cuando encuentro a gente con opiniones que me parecen extraas, hago un esfuerzo deliberado para \'llegar\' al interior de esa persona, para intentar ver cmo pueden tener esas opiniones.';
$string['attls19short'] = 'hacer esfuerzos para llegar al otro';
$string['attls1short'] = 'centrarse en la calidad del argumento';
$string['attls2'] = 'Me gusta ser el abogado del diablo, sosteniendo lo contrario de lo que alguien dice.';
$string['attls20'] = 'Dedico tiempo a comprender qu est \'equivocado\' en las cosas. Por ejemplo, en una interpretacin literaria busco algo que no est suficientemente bien argumentado.';
$string['attls20short'] = 'qu est equivocado?';
$string['attls2short'] = 'ser el abogado del diablo';
$string['attls3'] = 'Me gusta entender \'de dnde vienen\' los dems, que experiencias les han hecho sentir de la forma en que lo hacen.';
$string['attls3short'] = 'de dnde vienen los dems';
$string['attls4'] = 'La parte ms importante de mi educacin ha sido aprender a entender a la gente que es diferente a m';
$string['attls4short'] = 'entender a la gente diferente';
$string['attls5'] = 'Siento que la mejor manera de conseguir mi propia identidad es interactuar con gente diferente.';
$string['attls5short'] = 'interactuar con la diversidad';
$string['attls6'] = 'Me encanta or las opiniones de gente que viene de entornos diferentes al mo --me ayuda a entender cmo cosas iguales pueden ser vistas de maneras diferentes.';
$string['attls6short'] = 'me encanta or opiniones';
$string['attls7'] = 'Veo que puedo fortalecer mi propia posicin discutiendo con gente que discrepa conmigo.';
$string['attls7short'] = 'fortalecer a travs del debate';
$string['attls8'] = 'Estoy siempre interesado en conocer por qu la gente dice y cree las cosas y la forma en que lo hacen.';
$string['attls8short'] = 'saber por qu';
$string['attls9'] = 'A menudo me encuentro a m mismo discutiendo con los autores de los libros que leo, intentando entender por qu estn equivocados.';
$string['attls9short'] = 'discutir con autores';
$string['attlsintro'] = 'El propsito de este cuestionario es ayudarnos a evaluar sus actitudes hacia el pensamiento y el aprendizaje.
No hay respuestas \'correctas\' o \'equivocadas\', nos interesa slo su opinin. Sus respuestas sern tratadas con alto grado de confidencialidad y no afectarn su evaluacin.';
$string['attlsm1'] = 'Actitudes hacia el pensamiento y el aprendizaje';
$string['attlsm2'] = 'Aprendizaje Colaborativo';
$string['attlsm3'] = 'Aprendizaje Individualizado';
$string['attlsmintro'] = 'En discusin...';
$string['attlsname'] = 'ATTLS (versin de 20 elementos)';
$string['ciq1'] = 'En qu momento, durante la clase, se sinti ms involucrado como estudiante?';
$string['ciq1short'] = 'Muy implicado';
$string['ciq2'] = 'En qu momento, durante la clase, se sinti ms distanciado como estudiante?';
$string['ciq2short'] = 'Muy distanciado';
$string['ciq3'] = 'Qu accin, de cualquiera de sus participantes, le ha parecido ms til o positiva dentro del foro?';
$string['ciq3short'] = 'Momento til';
$string['ciq4'] = 'Qu accin dentro del foro le ha parecido ms compleja o confusa por parte de cualquiera de sus participantes?';
$string['ciq4short'] = 'Momento confuso';
$string['ciq5'] = 'Qu evento le ha sorprendido ms?';
$string['ciq5short'] = 'Momento sorpresivo';
$string['ciqintro'] = 'Responda las siguientes preguntas pensando en los eventos ocurridos durante la semana pasada en esta clase.';
$string['ciqname'] = 'Incidentes crticos';
$string['clicktocontinue'] = 'Haz clic aqu para continuar';
$string['clicktocontinuecheck'] = 'Haz clic aqu para revisar y continuar';
$string['colles1'] = 'mi aprendizaje se centra en asuntos que me interesan.';
$string['colles10'] = 'Pido a otros estudiantes que me expliquen sus ideas.';
$string['colles10short'] = 'Pido explicaciones';
$string['colles11'] = 'otros estudiantes me piden que explique mis ideas.';
$string['colles11short'] = 'Se me pide que explique';
$string['colles12'] = 'otros estudiantes responden a mis ideas.';
$string['colles12short'] = 'los estudiantes me responden';
$string['colles13'] = 'el tutor me estimula a reflexionar.';
$string['colles13short'] = 'el tutor estimula la reflexin';
$string['colles14'] = 'el tutor me anima a participar.';
$string['colles14short'] = 'el tutor me anima';
$string['colles15'] = 'el tutor ejemplifica las buenas disertaciones.';
$string['colles15short'] = 'el tutor ejemplifica las disertaciones';
$string['colles16'] = 'el tutor ejemplifica la auto reflexin crtica.';
$string['colles16short'] = 'el tutor ejemplifica la auto reflexin';
$string['colles17'] = 'otros estudiantes me animan a participar.';
$string['colles17short'] = 'los estudiantes me animan';
$string['colles18'] = 'los otros estudiantes elogian mi contribucin.';
$string['colles18short'] = 'los estudiantes me elogian';
$string['colles19'] = 'otros estudiantes valoran mi contribucin.';
$string['colles19short'] = 'los estudiantes me valoran';
$string['colles1short'] = 'centrado en temas interesantes';
$string['colles2'] = 'lo que aprendo es importante para mi prctica profesional.';
$string['colles20'] = 'los otros estudiantes empatizan con mis esfuerzos por aprender.';
$string['colles20short'] = 'los estudiantes empatizan';
$string['colles21'] = 'entiendo bien los mensajes de otros estudiantes';
$string['colles21short'] = 'Entiendo a los otros estudiantes';
$string['colles22'] = 'los otros estudiantes entienden bien mis mensajes.';
$string['colles22short'] = 'los estudiantes me entienden';
$string['colles23'] = 'entiendo bien los mensajes del tutor.';
$string['colles23short'] = 'Entiendo al tutor';
$string['colles24'] = 'el tutor entiende bien mis mensajes.';
$string['colles24short'] = 'el tutor me comprende';
$string['colles2short'] = 'importante para mi prctica';
$string['colles3'] = 'aprendo cmo mejorar mi prctica profesional.';
$string['colles3short'] = 'mejoro mi prctica';
$string['colles4'] = 'lo que aprendo tiene relacin con mi prctica profesional';
$string['colles4short'] = 'tiene relacin con mi prctica';
$string['colles5'] = 'Pienso crticamente sobre cmo aprendo.';
$string['colles5short'] = 'Soy crtico con mi aprendizaje';
$string['colles6'] = 'Pienso crticamente sobre mis propias ideas.';
$string['colles6short'] = 'Soy crtico con mis propias ideas';
$string['colles7'] = 'Pienso crticamente sobre la ideas de otros estudiantes.';
$string['colles7short'] = 'Soy crtico con otros estudiantes';
$string['colles8'] = 'Pienso crticamente sobre las ideas que leo.';
$string['colles8short'] = 'Soy crtico con lo que leo';
$string['colles9'] = 'Explico mis ieas a otros estudiantes.';
$string['colles9short'] = 'Explico mis ideas';
$string['collesaintro'] = 'El propsito de esta encuesta es ayudarnos a entender hasta qu punto la presentacin en lnea de esta unidad le facilit el aprendizaje.
Cada una de las 24 declaraciones siguientes le interroga acerca de su experiencia en esta unidad.
No hay respuestas \'correctas\' o \'equivocadas\', nosotros estamos interesados slo en su opinin. Sus respuestas sern tratadas con alto grado de confidencialidad y no afectarn su evaluacin.
Sus respuestas, pensadas cuidadosamente, nos ayudarn a mejorar la manera de presentar esta unidad en el futuro.
Muchas gracias.';
$string['collesaname'] = 'COLLES (Actual)';
$string['collesapintro'] = 'El propsito de este cuestionario es ayudarnos a entender hasta qu punto la presentacin en lnea de esta unidad le facilit el aprendizaje.
Cada una de las declaraciones siguientes le pedirn que compare su experiencia <strong>favorita</strong> (ideal) y su experiencia <strong>real</strong> en esta unidad. Sus respuestas sern tratadas con alto grado de confidencialidad y no afectarn su evaluacin.
Sus respuestas, pensadas cuidadosamente, nos ayudarn a mejorar la manera de presentar esta unidad en el futuro.
Muchas gracias por su colaboracin.';
$string['collesapname'] = 'COLLES (Favorita y actual)';
$string['collesm1'] = 'Relevancia';
$string['collesm1short'] = 'Relevancia';
$string['collesm2'] = 'Pensamiento reflexivo';
$string['collesm2short'] = 'Pensamiento reflexivo';
$string['collesm3'] = 'Interactividad';
$string['collesm3short'] = 'Interactividad';
$string['collesm4'] = 'Apoyo del tutor';
$string['collesm4short'] = 'Apoyo del tutor';
$string['collesm5'] = 'Apoyo de compaeros';
$string['collesm5short'] = 'Apoyo de compaeros';
$string['collesm6'] = 'Interpretacin';
$string['collesm6short'] = 'Interpretacin';
$string['collesmintro'] = 'En esta unidad en lnea...';
$string['collespintro'] = 'El propsito de esta encuesta es ayudarnos a entender lo que usted valora en una experiencia de aprendizaje en lnea.
Cada una de las 24 declaraciones siguientes le interrogan sobre su experiencia <strong>favorita</em> (ideal) en esta unidad.
No existen respuestas \'correctas\' o \'equivocadas\', a nosotros nos interesa slo su opinin. Sus respuestas sern tratadas con alto grado de confidencialidad y no afectarn su evaluacin.
Sus respuestas, pensadas cuidadosamente, nos ayudarn a mejorar la manera de presentar esta unidad en el futuro.
Muchas gracias por su colaboracin.';
$string['collespname'] = 'COLLES (Preferida)';
$string['done'] = 'Hecho';
$string['download'] = 'Descargar';
$string['downloadexcel'] = 'Descargar como hoja de clculo';
$string['downloadinfo'] = 'Puede descargar la informacin completa en un formato que pueda ser analizado por un programa de hojas de clculo';
$string['downloadtext'] = 'Descargar como texto';
$string['editingasurvey'] = 'Editando informacin';
$string['guestsnotallowed'] = 'Los invitados no pueden participar en las encuestas';
$string['helpsurveys'] = 'Ayuda sobre los diferentes tipos de informacin';
$string['howlong'] = 'Cunto tiempo le llev completar este cuestionario?';
$string['howlongoptions'] = 'menos de 1 <abbr title=minuto>min.</abbr>, 1-2 <abbr title=minuto>min.</abbr>,  2-3 <abbr title=minuto>min.</abbr>,  3-4 <abbr title=minuto>min.</abbr>,  4-5 <abbr title=minuto>min.</abbr>,  5-10 <abbr title=minuto>min.</abbr>, ms de 10 minutos.';
$string['ifoundthat'] = 'Encontrado:';
$string['introtext'] = 'Texto de introduccin';
$string['ipreferthat'] = 'Prefiero esto';
$string['modulename'] = 'Encuesta';
$string['modulenameplural'] = 'Encuestas';
$string['name'] = 'Nombre';
$string['newsurveyresponses'] = 'Nuevas respuestas a la encuesta';
$string['nobodyyet'] = 'Nadie ha completado esta encuesta an';
$string['notdone'] = 'An no se ha hecho';
$string['notes'] = 'Su anlisis privado y sus notas';
$string['othercomments'] = 'Tiene algn otro comentario?';
$string['peoplecompleted'] = '$a personas han completado esta encuesta';
$string['preferred'] = 'Preferido';
$string['preferredclass'] = 'Clase preferida';
$string['preferredstudent'] = '$a preferido';
$string['question'] = 'Pregunta';
$string['questions'] = 'Preguntas';
$string['questionsnotanswered'] = 'Algunas de las preguntas con opcin mltiple no han sido contestadas.';
$string['report'] = 'Informe de la encuesta';
$string['savednotes'] = 'Sus notas se han guardado';
$string['scaleagree5'] = 'en total desacuerdo, un poco en desacuerdo, ni de acuerdo ni en desacuerdo, un poco de acuerdo, totalmente de acuerdo';
$string['scales'] = 'Escalas';
$string['scaletimes5'] = 'casi nunca, rara vez, alguna vez, a menudo, casi siempre';
$string['seemoredetail'] = 'Haga clic aqu para ver ms detalles';
$string['selectedquestions'] = 'Preguntas seleccionadas de una escala, todos los estudiantes';
$string['summary'] = 'Resumen';
$string['surveycompleted'] = 'Usted ha completado la encuesta. La grfica siguiente muestra sus resultados comparados con el promedio de la clase.';
$string['surveyname'] = 'Nombre de la encuesta';
$string['surveysaved'] = 'Encuesta guardada';
$string['surveytype'] = 'Tipo de encuesta';
$string['thanksforanswers'] = 'Gracias por responder a esta encuesta, $a';
$string['time'] = 'Tiempo';
$string['viewsurveyresponses'] = 'Ver las respuestas a la encuesta $a ';

?>

==> moodle-1.5.3.tgz: moodle/lang/es/survey.php <==
<?PHP // $Id$ 
      // survey.php - created with Moodle 1.3 (2004052500)


$string['actual'] = 'Actual';
$string['actualclass'] = 'Clase actual';
$string['actualstudent'] = '$a actual';
$string['allquestions'] = 'Todas las preguntas en orden, todos los estudiantes';
$string['allscales'] = 'Todas las escalas, todos los estudiantes';
$string['alreadysubmitted'] = 'Ya envi esta informacin';
$string['analysisof'] = 'Anlisis de $a';
$string['answers'] = 'Respuestas';
$string['attls1'] = 'Al evaluar lo que alguien dice, me centro en lo que dice y no en quin es.';
$string['attls10'] = 'Para m es importante mantenerme lo ms objetivo posible cuando analizo algo.';
$string['attls10short'] = 'Sea objetivo';
$string['attls11'] = 'Trato de pensar con las personas en lugar de contra ellas.';
$string['attls11short'] = 'Piense CON las personas';
$string['attls12'] = 'Tengo un criterio que utilizo para evaluar argumentos.';
$string['attls12short'] = 'Utilice un criterio para evaluar';
$string['attls13'] = 'Prefiero tratar de entender a los dems antes que evaluarlos.';
$string['attls13short'] = 'Trate de entender';
$string['attls14'] = 'Trato de sealar las debilidades en la manera de pensar de los dems para ayudarles a clarificar sus razonamientos.';
$string['attls14short'] = 'Seale los puntos dbiles';
$string['attls15'] = 'Trato de colocarme en el lugar de los dems para comprender cmo piensan y por qu.';
$string['attls15short'] = 'Me coloco en el lugar de los otros';
$string['attls16'] = 'Alguien podra llamar a mi manera de analizar las cosas \'ponerlas a prueba\' porque yo tengo en cuenta todas las evidencias cuidadosamente.';
$string['attls16short'] = 'poner a prueba';
$string['attls17'] = 'Cuando se trata de resolver problemas, valoro el uso de la lgica y de la razn por encima de mis propios intereses.';
$string['attls17short'] = 'valoro sobre todo la lgica';
$string['attls18'] = 'puedo llegar a entender las opiniones que difieren de la ma a travs de la empata';
$string['attls18short'] = 'entendimiento desde la empata';
$string['attls19'] = 'Cuando encuentro a gente con opiniones que me parecen extraas, hago un esfuerzo deliberado para \'llegar\' al interior de esa persona, para intentar ver cmo pueden tener esas opiniones.';
$string['attls19short'] = 'hacer esfuerzos para llegar al otro';
$string['attls1short'] = 'centrarse en la calidad del argumento';
$string['attls2'] = 'Me gusta ser el abogado del diablo, sosteniendo lo contrario de lo que alguien dice.';
$string['attls20'] = 'Dedico tiempo a comprender qu est \'equivocado\' en las cosas. Por ejemplo, en una interpretacin literaria busco algo que no est suficientemente bien argumentado.';
$string['attls20short'] = 'qu est equivocado?';
$string['attls2short'] = 'ser el abogado del diablo';
$string['attls3'] = 'Me gusta entender \'de dnde vienen\' los dems, que experiencias les han hecho sentir de la forma en que lo hacen.';
$string['attls3short'] = 'de dnde vienen los dems';
$string['attls4'] = 'La parte ms importante de mi educacin ha sido aprender a entender a la gente que es diferente a m';
$string['attls4short'] = 'entender a la gente diferente';
$string['attls5'] = 'Siento que la mejor manera de conseguir mi propia identidad es interactuar con gente diferente.';
$string['attls5short'] = 'interactuar con la diversidad';
$string['attls6'] = 'Me encanta or las opiniones de gente que viene de entornos diferentes al mo --me ayuda a entender cmo cosas iguales pueden ser vistas de maneras diferentes.';
$string['attls6short'] = 'me encanta or opiniones';
$string['attls7'] = 'Veo que puedo fortalecer mi propia posicin discutiendo con gente que discrepa conmigo.';
$string['attls7short'] = 'fortalecer a travs del debate';
$string['attls8'] = 'Estoy siempre interesado en conocer por qu la gente dice y cree las cosas y la forma en que lo hacen.';
$string['attls8short'] = 'saber por qu';
$string['attls9'] = 'A menudo me encuentro a m mismo discutiendo con los autores de los libros que leo, intentando entender por qu estn equivocados.';
$string['attls9short'] = 'discutir con autores';
$string['attlsintro'] = 'El propsito de este cuestionario es ayudarnos a evaluar sus actitudes hacia el pensamiento y el aprendizaje.
No hay respuestas \'correctas\' o \'equivocadas\', nos interesa slo su opinin. Sus respuestas sern tratadas con alto grado de confidencialidad y no afectarn su evaluacin.';
$string['attlsm1'] = 'Actitudes hacia el pensamiento y el aprendizaje';
$string['attlsm2'] = 'Aprendizaje Colaborativo';
$string['attlsm3'] = 'Aprendizaje Individualizado';
$string['attlsmintro'] = 'En discusin...';
$string['attlsname'] = 'ATTLS (versin de 20 elementos)';
$string['ciq1'] = 'En qu momento, durante la clase, se sinti ms involucrado como estudiante?';
$string['ciq1short'] = 'Muy implicado';
$string['ciq2'] = 'En qu momento, durante la clase, se sinti ms distanciado como estudiante?';
$string['ciq2short'] = 'Muy distanciado';
$string['ciq3'] = 'Qu accin, de cualquiera de sus participantes, le ha parecido ms til o positiva dentro del foro?';
$string['ciq3short'] = 'Momento til';
$string['ciq4'] = 'Qu accin dentro del foro le ha parecido ms compleja o confusa por parte de cualquiera de sus participantes?';
$string['ciq4short'] = 'Momento confuso';
$string['ciq5'] = 'Qu evento le ha sorprendido ms?';
$string['ciq5short'] = 'Momento sorpresivo';
$string['ciqintro'] = 'Responda las siguientes preguntas pensando en los eventos ocurridos durante la semana pasada en esta clase.';
$string['ciqname'] = 'Incidentes crticos';
$string['clicktocontinue'] = 'Haz clic aqu para continuar';
$string['clicktocontinuecheck'] = 'Haz clic aqu para revisar y continuar';
$string['colles1'] = 'mi aprendizaje se centra en asuntos que me interesan.';
$string['colles10'] = 'Pido a otros estudiantes que me expliquen sus ideas.';
$string['colles10short'] = 'Pido explicaciones';
$string['colles11'] = 'otros estudiantes me piden que explique mis ideas.';
$string['colles11short'] = 'Se me pide que explique';
$string['colles12'] = 'otros estudiantes responden a mis ideas.';
$string['colles12short'] = 'los estudiantes me responden';
$string['colles13'] = 'el tutor me estimula a reflexionar.';
$string['colles13short'] = 'el tutor estimula la reflexin';
$string['colles14'] = 'el tutor me anima a participar.';
$string['colles14short'] = 'el tutor me anima';
$string['colles15'] = 'el tutor ejemplifica las buenas disertaciones.';
$string['colles15short'] = 'el tutor ejemplifica las disertaciones';
$string['colles16'] = 'el tutor ejemplifica la auto reflexin crtica.';
$string['colles16short'] = 'el tutor ejemplifica la auto reflexin';
$string['colles17'] = 'otros estudiantes me animan a participar.';
$string['colles17short'] = 'los estudiantes me animan';
$string['colles18'] = 'los otros estudiantes elogian mi contribucin.';
$string['colles18short'] = 'los estudiantes me elogian';
$string['colles19'] = 'otros estudiantes valoran mi contribucin.';
$string['colles19short'] = 'los estudiantes me valoran';
$string['colles1short'] = 'centrado en temas interesantes';
$string['colles2'] = 'lo que aprendo es importante para mi prctica profesional.';
$string['colles20'] = 'los otros estudiantes empatizan con mis esfuerzos por aprender.';
$string['colles20short'] = 'los estudiantes empatizan';
$string['colles21'] = 'entiendo bien los mensajes de otros estudiantes';
$string['colles21short'] = 'Entiendo a los otros estudiantes';
$string['colles22'] = 'los otros estudiantes entienden bien mis mensajes.';
$string['colles22short'] = 'los estudiantes me entienden';
$string['colles23'] = 'entiendo bien los mensajes del tutor.';
$string['colles23short'] = 'Entiendo al tutor';
$string['colles24'] = 'el tutor entiende bien mis mensajes.';
$string['colles24short'] = 'el tutor me comprende';
$string['colles2short'] = 'importante para mi prctica';
$string['colles3'] = 'aprendo cmo mejorar mi prctica profesional.';
$string['colles3short'] = 'mejoro mi prctica';
$string['colles4'] = 'lo que aprendo tiene relacin con mi prctica profesional';
$string['colles4short'] = 'tiene relacin con mi prctica';
$string['colles5'] = 'Pienso crticamente sobre cmo aprendo.';
$string['colles5short'] = 'Soy crtico con mi aprendizaje';
$string['colles6'] = 'Pienso crticamente sobre mis propias ideas.';
$string['colles6short'] = 'Soy crtico con mis propias ideas';
$string['colles7'] = 'Pienso crticamente sobre la ideas de otros estudiantes.';
$string['colles7short'] = 'Soy crtico con otros estudiantes';
$string['colles8'] = 'Pienso crticamente sobre las ideas que leo.';
$string['colles8short'] = 'Soy crtico con lo que leo';
$string['colles9'] = 'Explico mis ieas a otros estudiantes.';
$string['colles9short'] = 'Explico mis ideas';
$string['collesaintro'] = 'El propsito de esta encuesta es ayudarnos a entender hasta qu punto la presentacin en lnea de esta unidad le facilit el aprendizaje.
Cada una de las 24 declaraciones siguientes le interroga acerca de su experiencia en esta unidad.
No hay respuestas \'correctas\' o \'equivocadas\', nosotros estamos interesados slo en su opinin. Sus respuestas sern tratadas con alto grado de confidencialidad y no afectarn su evaluacin.
Sus respuestas, pensadas cuidadosamente, nos ayudarn a mejorar la manera de presentar esta unidad en el futuro.
Muchas gracias.';
$string['collesaname'] = 'COLLES (Actual)';
$string['collesapintro'] = 'El propsito de este cuestionario es ayudarnos a entender hasta qu punto la presentacin en lnea de esta unidad le facilit el aprendizaje.
Cada una de las declaraciones siguientes le pedirn que compare su experiencia <strong>favorita</strong> (ideal) y su experiencia <strong>real</strong> en esta unidad. Sus respuestas sern tratadas con alto grado de confidencialidad y no afectarn su evaluacin.
Sus respuestas, pensadas cuidadosamente, nos ayudarn a mejorar la manera de presentar esta unidad en el futuro.
Muchas gracias por su colaboracin.';
$string['collesapname'] = 'COLLES (Favorita y actual)';
$string['collesm1'] = 'Relevancia';
$string['collesm1short'] = 'Relevancia';
$string['collesm2'] = 'Pensamiento reflexivo';
$string['collesm2short'] = 'Pensamiento reflexivo';
$string['collesm3'] = 'Interactividad';
$string['collesm3short'] = 'Interactividad';
$string['collesm4'] = 'Apoyo del tutor';
$string['collesm4short'] = 'Apoyo del tutor';
$string['collesm5'] = 'Apoyo de compaeros';
$string['collesm5short'] = 'Apoyo de compaeros';
$string['collesm6'] = 'Interpretacin';
$string['collesm6short'] = 'Interpretacin';
$string['collesmintro'] = 'En esta unidad en lnea...';
$string['collespintro'] = 'El propsito de esta encuesta es ayudarnos a entender lo que usted valora en una experiencia de aprendizaje en lnea.
Cada una de las 24 declaraciones siguientes le interrogan sobre su experiencia <strong>favorita</strong> (ideal) en esta unidad.
No existen respuestas \'correctas\' o \'equivocadas\', a nosotros nos interesa slo su opinin. Sus respuestas sern tratadas con alto grado de confidencialidad y no afectarn su evaluacin.
Sus respuestas, pensadas cuidadosamente, nos ayudarn a mejorar la manera de presentar esta unidad en el futuro.
Muchas gracias por su colaboracin.';
$string['collespname'] = 'COLLES (Preferida)';
$string['done'] = 'Hecho';
$string['download'] = 'Descargar';
$string['downloadexcel'] = 'Descargar como hoja de clculo';
$string['downloadinfo'] = 'Puede descargar la informacin completa en un formato que pueda ser analizado por un programa de hojas de clculo';
$string['downloadtext'] = 'Descargar como texto';
$string['editingasurvey'] = 'Editando informacin';
$string['guestsnotallowed'] = 'Los invitados no pueden participar en las encuestas';
$string['helpsurveys'] = 'Ayuda sobre los diferentes tipos de informacin';
$string['howlong'] = 'Cunto tiempo le llev completar este cuestionario?';
$string['howlongoptions'] = 'menos de 1 <abbr title=minuto>min.</abbr>, 1-2 <abbr title=minuto>min.</abbr>,  2-3 <abbr title=minuto>min.</abbr>,  3-4 <abbr title=minuto>min.</abbr>,  4-5 <abbr title=minuto>min.</abbr>,  5-10 <abbr title=minuto>min.</abbr>, ms de 10 minutos.';
$string['ifoundthat'] = 'Encontrado:';
$string['introtext'] = 'Texto de introduccin';
$string['ipreferthat'] = 'Prefiero esto';
$string['modulename'] = 'Encuesta';
$string['modulenameplural'] = 'Encuestas';
$string['name'] = 'Nombre';
$string['newsurveyresponses'] = 'Nuevas respuestas a la encuesta';
$string['nobodyyet'] = 'Nadie ha completado esta encuesta an';
$string['notdone'] = 'An no se ha hecho';
$string['notes'] = 'Su anlisis privado y sus notas';
$string['othercomments'] = 'Tiene algn otro comentario?';
$string['peoplecompleted'] = '$a personas han completado esta encuesta';
$string['preferred'] = 'Preferido';
$string['preferredclass'] = 'Clase preferida';
$string['preferredstudent'] = '$a preferido';
$string['question'] = 'Pregunta';
$string['questions'] = 'Preguntas';
$string['questionsnotanswered'] = 'Algunas de las preguntas con opcin mltiple no han sido contestadas.';
$string['report'] = 'Informe de la encuesta';
$string['savednotes'] = 'Sus notas se han guardado';
$string['scaleagree5'] = 'en total desacuerdo, un poco en desacuerdo, ni de acuerdo ni en desacuerdo, un poco de acuerdo, totalmente de acuerdo';
$string['scales'] = 'Escalas';
$string['scaletimes5'] = 'casi nunca, rara vez, alguna vez, a menudo, casi siempre';
$string['seemoredetail'] = 'Haga clic aqu para ver ms detalles';
$string['selectedquestions'] = 'Preguntas seleccionadas de una escala, todos los estudiantes';
$string['summary'] = 'Resumen';
$string['surveycompleted'] = 'Usted ha completado la encuesta. La grfica siguiente muestra sus resultados comparados con el promedio de la clase.';
$string['surveyname'] = 'Nombre de la encuesta';
$string['surveysaved'] = 'Encuesta guardada';
$string['surveytype'] = 'Tipo de encuesta';
$string['thanksforanswers'] = 'Gracias por responder a esta encuesta, $a';
$string['time'] = 'Tiempo';
$string['viewsurveyresponses'] = 'Ver las respuestas a la encuesta $a ';

?>
